// eslint-disable-next-line import/no-extraneous-dependencies
import React, { useContext, useEffect, useMemo, useRef } from 'react';
import { textToHTMLId } from "../heading";
import { DocAnchorContext } from "./docAnchorContext";
import { CLASSNAME_MARKDOWN_CONTENT } from "../../../constants";
import styles from "./docAnchor.module.scss";

// only allow to render one anchor in single page
let pageUniqueAnchorId = null;
export function DocAnchor() {
  const {
    anchorList: anchorListFromContext,
    updateAnchorList
  } = useContext(DocAnchorContext);
  const refHeadingQueryTimer = useRef(null);

  // only allow to render one anchor in the same page
  const isTheOnlyAnchorToRender = useMemo(() => {
    const thisId = Math.random().toFixed(10).slice(2);
    if (!pageUniqueAnchorId) {
      pageUniqueAnchorId = thisId;
    }
    return thisId === pageUniqueAnchorId;
  }, []);
  useEffect(() => {
    if (isTheOnlyAnchorToRender) {
      refHeadingQueryTimer.current = setInterval(() => {
        var _document$querySelect;
        const titles = (_document$querySelect = document.querySelector(`.${CLASSNAME_MARKDOWN_CONTENT}`)) === null || _document$querySelect === void 0 ? void 0 : _document$querySelect.querySelectorAll('h1, h2');
        if (titles !== null && titles !== void 0 && titles.length) {
          updateAnchorList([...titles].map(title => {
            return {
              id: title.getAttribute('id'),
              text: title.textContent,
              depth: +title.tagName.slice(-1)
            };
          }).filter(({
            id
          }) => !!id), 'prepend');
          window.clearInterval(refHeadingQueryTimer.current);
        }
      }, 200);
    }
    return () => {
      window.clearInterval(refHeadingQueryTimer.current);
    };
  }, []);
  useEffect(() => {
    return () => {
      // reset page unique anchor id to null after this anchor destroyed
      if (isTheOnlyAnchorToRender) {
        pageUniqueAnchorId = null;
      }
    };
  }, []);
  return isTheOnlyAnchorToRender && anchorListFromContext.length ? /*#__PURE__*/React.createElement("ul", {
    className: styles.docAnchor
  }, anchorListFromContext.map(({
    depth,
    text,
    id
  }, index) => {
    return /*#__PURE__*/React.createElement("li", {
      key: index
    }, /*#__PURE__*/React.createElement("a", {
      className: styles.anchor,
      style: {
        marginLeft: 16 * (depth - 1)
      },
      href: `#${id || textToHTMLId(text)}`
    }, text));
  })) : null;
}