// eslint-disable-next-line import/no-extraneous-dependencies
import React, { useContext, useEffect, useMemo } from 'react';
import { Table } from "../../baseUI/table";
import { CodeHighlighter } from "../../baseUI/highlighter";
import { DocAnchorContext } from "../../markdown/components/docAnchor";
import styles from "./propertiesTable.module.scss";

// Type from @arco-cli/react/dist/tsdoc/types

export function PropertiesTable({
  doclet
}) {
  const {
    updateAnchorList
  } = useContext(DocAnchorContext);
  const anchorList = useMemo(() => {
    const list = [];
    if (doclet !== null && doclet !== void 0 && doclet.length) {
      const apiTitleText = 'API';
      list.push({
        text: apiTitleText,
        depth: 1,
        content: /*#__PURE__*/React.createElement("h1", {
          id: apiTitleText,
          key: apiTitleText
        }, apiTitleText)
      });
      list.push(...doclet.map(({
        name,
        type,
        properties
      }, index) => ({
        text: name,
        depth: 2,
        content: /*#__PURE__*/React.createElement("div", {
          key: index,
          className: styles.table
        }, /*#__PURE__*/React.createElement("h2", {
          id: name,
          className: styles.tableTitle
        }, name), type ? /*#__PURE__*/React.createElement(CodeHighlighter, {
          language: "typescript"
        }, type) : null, properties.length ? /*#__PURE__*/React.createElement(Table, {
          headings: ['name', 'type', 'default', 'description'],
          rows: properties
        }) : null)
      })));
    }
    return list;
  }, [doclet]);
  useEffect(() => {
    updateAnchorList(anchorList.map(({
      text,
      depth
    }) => ({
      text,
      depth
    })));
  }, [doclet]);
  return anchorList.length ? /*#__PURE__*/React.createElement("div", {
    className: styles.propertiesTable
  }, anchorList.map(({
    content
  }) => content)) : null;
}