// eslint-disable-next-line import/no-extraneous-dependencies
import React, { useContext, useMemo } from 'react';
// eslint-disable-next-line import/no-extraneous-dependencies
import { Link } from 'react-router-dom';
import { Menu } from '@arco-design/web-react';
import { IconApps, IconCode, IconFolder } from '@arco-design/web-react/icon';
import { WorkspaceContext } from "../../workspaceContext";
import styles from "./componentMenu.module.scss";
const MENU_ITEM_OVERVIEW = '__overview';
export function ComponentMenu({
  componentId,
  onComponentChange
}) {
  const {
    components
  } = useContext(WorkspaceContext);
  const routeInfo = useMemo(() => {
    const results = [];
    const groupByPackage = [];
    for (const component of components.sort((comA, comB) => comA.id > comB.id ? 1 : -1)) {
      let group = groupByPackage.find(node => node.package === component.packageName);
      if (!group) {
        group = {
          package: component.packageName,
          components: []
        };
        groupByPackage.push(group);
      }
      group.components.push(component);
    }
    for (const {
      package: packageName,
      components
    } of groupByPackage) {
      const getMenuItemProps = component => {
        const {
          id,
          name
        } = component;
        return {
          key: id,
          title: /*#__PURE__*/React.createElement(Link, {
            to: `/${id}`
          }, /*#__PURE__*/React.createElement(IconCode, null), name)
        };
      };
      if (components.length > 1) {
        results.push({
          key: packageName,
          title: /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(IconFolder, null), packageName),
          children: components.map(getMenuItemProps)
        });
      } else if (components.length) {
        results.push(getMenuItemProps(components[0]));
      }
    }
    return results;
  }, []);
  return /*#__PURE__*/React.createElement(Menu, {
    className: styles.componentMenu,
    autoOpen: true,
    mode: "vertical",
    selectedKeys: [componentId],
    onClickMenuItem: onComponentChange
  }, /*#__PURE__*/React.createElement(Menu.Item, {
    key: MENU_ITEM_OVERVIEW
  }, /*#__PURE__*/React.createElement(Link, {
    className: styles.menuItemLink,
    to: "/"
  }, /*#__PURE__*/React.createElement(IconApps, null), "Overview")), routeInfo.map(({
    key,
    title,
    children
  }) => {
    return children !== null && children !== void 0 && children.length ? /*#__PURE__*/React.createElement(Menu.SubMenu, {
      key: key,
      title: title
    }, children.map(({
      key,
      title
    }) => /*#__PURE__*/React.createElement(Menu.Item, {
      key: key
    }, title))) : /*#__PURE__*/React.createElement(Menu.Item, {
      key: key
    }, title);
  }));
}